"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs_1 = __importDefault(require("fs"));
const path_1 = __importDefault(require("path"));
const chalk_1 = __importDefault(require("chalk"));
const node_emoji_1 = __importDefault(require("node-emoji"));
const inquirer_1 = __importDefault(require("inquirer"));
const Config_1 = require("../Config");
const graphql_1 = require("../utils/graphql");
const showSpinnerWhileProcessing_1 = require("../utils/showSpinnerWhileProcessing");
const aboutMeQuery = fs_1.default.readFileSync(path_1.default.join(__dirname, "..", "queries", "aboutMe.graphql"), "utf8");
exports.default = {
    command: "login",
    describe: "Check your environment to run ghi",
    builder: yargs => yargs.default("value", "true"),
    async handler(argv) {
        const config = Config_1.resolve(argv.config);
        if (config.token && config.login) {
            const { confirm } = await inquirer_1.default.prompt([
                {
                    name: "confirm",
                    type: "confirm",
                    message: `You're already logged in as ${config.login}. Do you want to continue?`,
                },
            ]);
            if (!confirm) {
                return;
            }
        }
        console.log(chalk_1.default.cyan("Welcome to ghi!"));
        console.log("To get started, open the following URL to generate a GitHub token");
        console.log("\n  https://github.com/settings/tokens/new?scopes=public_repo\n");
        const { token } = await inquirer_1.default.prompt([
            {
                name: "token",
                type: "password",
                mask: "*",
                message: "Please input your GitHub access token",
            },
        ]);
        const graphql = graphql_1.getClient({ token });
        const viewer = await showSpinnerWhileProcessing_1.showSpinnerWhileProcessing("Fetching your information from GitHub", async () => {
            const { viewer } = await graphql(aboutMeQuery);
            return viewer;
        });
        await showSpinnerWhileProcessing_1.showSpinnerWhileProcessing(`Saving credentials to ${chalk_1.default.dim(Config_1.DEFAULT_PATH)}`, async () => {
            fs_1.default.writeFileSync(Config_1.DEFAULT_PATH, JSON.stringify({ token, login: viewer.login }));
        });
        console.log(`Good job ${chalk_1.default.cyan(viewer.login)}!`);
        console.log(`This is the end of the instruction. If you have any questions, run 'ghi --help'.`);
        console.log(node_emoji_1.default.emojify(`Enjoy :crossed_fingers:`));
    },
};
